@@ -345,7 +345,7 @@ bool transformJPEG(const TQString& src, const TQString& destGiven,
     // And set finaly update the metadata to target file.
 
     TQImage img(destGiven);
-    TQImage exifThumbnail = img.scale(160, 120, TQ_ScaleMin);
+    TQImage exifThumbnail = img.scale(160, 120, TQImage::ScaleMin);
     exiv2Iface.load(destGiven);
     exiv2Iface.setImageOrientation(KExiv2Iface::KExiv2::ORIENTATION_NORMAL);
     exiv2Iface.setImageProgramId(TQString("Kipi-plugins"), TQString(kipiplugins_version));
