@@ -73,7 +73,7 @@ CameraSelection::CameraSelection(TQWidget* parent)
     helpButton_ = actionButton( Help );
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, TQT_SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, TQ_SLOT(slotHelp()), 0, -1, 0);
     helpButton_->setPopup( helpMenu->menu() );
 
     TQWidget *page = new TQWidget(this);
@@ -85,7 +85,7 @@ CameraSelection::CameraSelection(TQWidget* parent)
 
     TQGroupBox* mainBox = new TQGroupBox(page);
     mainBox->setTitle(i18n("Camera Configuration"));
-    mainBox->setColumnLayout(0, Qt::Vertical );
+    mainBox->setColumnLayout(0, TQt::Vertical );
     mainBox->layout()->setSpacing( 5 );
     mainBox->layout()->setMargin( 5 );
     TQGridLayout* mainBoxLayout = new TQGridLayout(mainBox->layout());
@@ -112,7 +112,7 @@ CameraSelection::CameraSelection(TQWidget* parent)
 
     TQGroupBox* portPathBox = new TQGroupBox(mainBox);
     portPathBox->setTitle( i18n("Camera Port Path"));
-    portPathBox->setColumnLayout(0, Qt::Vertical );
+    portPathBox->setColumnLayout(0, TQt::Vertical );
     portPathBox->layout()->setSpacing( 5 );
     portPathBox->layout()->setMargin( 5 );
     TQVBoxLayout* portPathBoxLayout = new TQVBoxLayout( portPathBox->layout() );
@@ -135,12 +135,12 @@ CameraSelection::CameraSelection(TQWidget* parent)
 
     // Connections --------------------------------------------------
 
-    connect(listView_, TQT_SIGNAL(selectionChanged(TQListViewItem *)),
-            this, TQT_SLOT(slotSelectionChanged(TQListViewItem *)));
+    connect(listView_, TQ_SIGNAL(selectionChanged(TQListViewItem *)),
+            this, TQ_SLOT(slotSelectionChanged(TQListViewItem *)));
 
-    connect(portButtonGroup_, TQT_SIGNAL(clicked(int)), this, TQT_SLOT(slotPortChanged()));
+    connect(portButtonGroup_, TQ_SIGNAL(clicked(int)), this, TQ_SLOT(slotPortChanged()));
 
-    connect(this, TQT_SIGNAL(okClicked()), this, TQT_SLOT(slotOkClicked()));
+    connect(this, TQ_SIGNAL(okClicked()), this, TQ_SLOT(slotOkClicked()));
 
     // Initialize  --------------------------------------------------
 
