@@ -40,7 +40,7 @@
 
   class Plugin_WallPaper : public KIPI::Plugin
   {
-  Q_OBJECT
+  TQ_OBJECT
   
 
    public:
